#
# spec file for package pyenv
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define pyenv_dir      %{_libexecdir}/pyenv
#
Name:           pyenv
Version:        1.2.9
Release:        lp151.1.2
Summary:        Python Version Management
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/yyuu/pyenv
Source0:        https://github.com/pyenv/pyenv/archive/v%{version}.tar.gz
Source1:        %{name}-rpmlintrc
Source2:        %{name}.rst
BuildRequires:  bash-completion
BuildRequires:  fdupes
BuildRequires:  fish
BuildRequires:  gcc
BuildRequires:  make
BuildRequires:  python3-Sphinx
BuildRequires:  zsh

%description
pyenv lets the user switch between multiple versions of Python.

This project was forked from rbenv and ruby-build, and modified for Python.

%package bash-completion
Summary:        Bash completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    packageand(pyenv:bash-completion)
BuildArch:      noarch

%description bash-completion
Bash command line completion support for %{name}.

%package fish-completion
Summary:        Fish completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    packageand(pyenv:fish)
BuildArch:      noarch

%description fish-completion
Fish command line completion support for %{name}.

%package zsh-completion
Summary:        Zsh completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    packageand(pyenv:zsh)
BuildArch:      noarch

%description zsh-completion
Zsh command line completion support for %{name}.

%prep
%setup -q
install -D %{SOURCE2} docs/%{name}.rst
sed -i -e '1s,^#!%{_bindir}/env bash,#!/bin/bash,' libexec/* pyenv.d/exec/pip-rehash/* plugins/python-build/bin/*

%build
##
pushd src
%configure
make %{?_smp_mflags}
popd

##
cat << EOF > docs/conf.py
# The master toctree document.
master_doc = '%{name}'

project = '%{name}'
copyright = '2017, Yuu Yamashita'
author = 'Yuu Yamashita'
# The short X.Y version.
version = '%{version}'
# The full version, including alpha/beta/rc tags.
release = version

# Usually you set "language" from the command line for these cases.
language = 'en'

man_pages = [
    (master_doc, 'pyenv', 'Simple Python Version Management',
     [author], 1)
]
man_show_urls=True
EOF

sphinx-build -b man -v docs man/

%install
mkdir -p %{buildroot}%{pyenv_dir} \
         %{buildroot}%{pyenv_dir}/plugins \
         %{buildroot}%{pyenv_dir}/shims/ \
         %{buildroot}%{pyenv_dir}/share/python-build/ \
         %{buildroot}%{_sysconfdir}/pyenv.d/ \
         %{buildroot}%{_bindir}

cp -R libexec %{buildroot}%{pyenv_dir}
cp -R bin %{buildroot}%{pyenv_dir}
cp -a pyenv.d %{buildroot}%{_sysconfdir}/

## Install shell completions:
install -D -m0644 completions/pyenv.bash %{buildroot}%{_datadir}/bash-completion/completions/pyenv
install -D -m0644 completions/pyenv.fish %{buildroot}%{_datadir}/fish/completions/pyenv.fish
install -D -m0644 completions/pyenv.zsh %{buildroot}%{_sysconfdir}/zsh_completion.d/pyenv

## Install manpage
install -D -m0644 man/%{name}.1 %{buildroot}%{_mandir}/man1/%{name}.1
pushd %{buildroot}%{_mandir}/man1/
 ln -s %{name}.1 python-build.1
popd

ln -s %{pyenv_dir}/bin/pyenv %{buildroot}%{_bindir}/pyenv

## python-build
pushd plugins/python-build
 install -m755 bin/* %{buildroot}%{pyenv_dir}/libexec
 cp -a share/python-build %{buildroot}%{pyenv_dir}/share/
popd

%fdupes %{buildroot}%{pyenv_dir}

%files
%doc CHANGELOG.md COMMANDS.md README.md
%license LICENSE
%exclude %{_sysconfdir}/pyenv.d/rehash/*/.gitignore

%config %{_sysconfdir}/pyenv.d/rehash/*.d/default.list
%config %{_sysconfdir}/pyenv.d/exec/pip-rehash.bash
%config %{_sysconfdir}/pyenv.d/rehash/*.bash

%{pyenv_dir}
%dir %{_sysconfdir}/pyenv.d
%dir %{_sysconfdir}/pyenv.d/exec/
%dir %{_sysconfdir}/pyenv.d/rehash/
%dir %{_sysconfdir}/pyenv.d/rehash/*.d/

%{_sysconfdir}/pyenv.d/exec/pip-rehash
%{_bindir}/pyenv
#
%{_mandir}/man1/%{name}.1%{?ext_man}
%{_mandir}/man1/python-build.1%{?ext_man}

%files bash-completion
%{_datadir}/bash-completion/completions/pyenv

%files fish-completion
%{_datadir}/fish/completions/pyenv.fish

%files zsh-completion
%config %{_sysconfdir}/zsh_completion.d/pyenv

%changelog
* Mon Jan 28 2019 thomas.schraitle@suse.com
- Update to 1.2.9:
  * python-build: Add CPython 3.7.2 and CPython 3.6.8 (#1256)
  * python-build: Add anaconda[23]-5.3.1 (#1246)
  * python-build: Add Anaconda 2018.12 (#1259)
  * python-build: Fix ironpython-dev git repo url (#1260)
  * python-build: Add OPENSSL_NO_SSL3 patch for CPython 3.3.7 (#1263)
- Version 1.2.8:
  * python-build: Add CPython 3.7.1
  * python-build: Add CPython 3.6.7
  * python-build: Add anaconda[23]-5.3.0 (#1220)
* Mon Jan 28 2019 thomas.schraitle@suse.com
- Install fish completion file to /usr/share/fish/completions/
* Thu Nov  8 2018 Antonio Larrosa <alarrosa@suse.com>
- Install bash completion file to /usr/share/bash-completion/completions
  and fix shebangs of several bash scripts.
* Tue Oct 30 2018 Jan Engelhardt <jengelh@inai.de>
- Trim bias from descriptions.
* Tue Oct 16 2018 Jon Brightwell <jon@moozaad.co.uk>
- Update to 1.2.7:
    python-build: Add CPython 3.5.6 (#1199)
    python-build: Add CPython 3.4.9
  1.2.5
    python-build: Add CPython 3.7.0 (#1177)
    python-build: Add micropython 1.9.4 (#1160)
    python-build: Add anaconda[23]-5.2.0 (#1165)
    pyenv: Fix seq(1) is not available on OpenBSD (#1166)
  1.2.4
    python-build: Add CPython 2.7.15
    python-build: Add PyPy 6.0.0
    python-build: Allow overriding HTTP client type based on environment variable PYTHON_BUILD_HTTP_CLIENT (#1126)
    python-build: Use version-specific get-pip.py when installing 2.6 and 3.2 (#1131)
    pyenv: Merge rbenv master (#1151)
    pyenv: Make pyenv-rehash safer for multiple processes (#1092)
* Wed Apr  4 2018 michele.bologna@suse.com
- Update to 1.2.3:
  * python-build: Add CPython 3.6.5
  * python-build: Set openssl PKG_CONFIG_PATH for python 3.7 (#1117)
  * python-build: Add ActivePython versions 2.7.14, 3.5.4, 3.6.0 (#1113)
  * python-build: Unset PIP_VERSION before invoking get-pip.py as a workaround for invalid truth value error (#1124)
* Tue Feb  6 2018 michele.bologna@suse.com
- Changelog for pyenv:
  Update to 1.2.1:
  * python-build: Add CPython 3.6.4
  * python-build: Add PyPy[23] 5.10
* Sun Sep 24 2017 thomas.schraitle@suse.com
  Update to 1.1.4
  * pyenv: Workaround for scripts in $PATH which needs to be
  source'd (#100, #688, #953)
  * python-build: Add support for PyPy3 executables like
  libpypy3-c.so (#955, #956)
  * python-build: Add CPython 2.7.14, 3.4.7, 3.5.4 (#965, #971, #980)
  * python-build: Add Jython 2.7.1 (#973)
  Spec changes:
  * Add pyenv.d/rehash/conda.d/ directory
  * Remove excluding .gitignore
* Sun Sep 17 2017 thomas.schraitle@suse.com
  More changes in the spec file:
  - Corrected path to Python definitions from python-build
  - Fixed install/uninstall and python-build
  They are now installed under libexec, not bin
  - Corrected manpage link creation to pyenv-{install,uninstall}
  - Switched from noarch to arch dependent due to pyenv-realpath.dylib
  - Add missing pyenv.d/rehash/conda.txt
* Sun Sep 17 2017 thomas.schraitle@suse.com
  Update to 1.1.3:
  * python-build: Add CPython 3.6.2 (#951)
  Spec file changes:
  * create manpage
  * subpackages for shell completion scripts
  * use spec-cleaner
  * add -rpmlintrc to suppress false error messages about
  wrong interpreter
  Details between 1.0.8 to 1.1.2, see below:
  v1.1.2:
  * pyenv: Fix incorrect pyenv --version output in v1.1.1 (#947)
  v1.1.1:
  * python-build: Update links to Portable Pypy 5.8-1 bugfix release (#939)
  * This is a minor release to update upstream links to Portable PyPy 5.8-1, see details at:
  squeaky-pl/portable-pypy#54
  v1.1.0:
  * pyenv: Merge rbenv master (#927)
  * python-build: Add PyPy 5.8.0 (#932)
  * python-build: Anaconda[23] 4.4.0 (#930)
  * python-build: Add micropython-dev (#920)
  v1.0.9:
  * fixes #865: Add support for PyPy2 5.7 and PyPy3 5.7
  No public changelog for v1.0.8.
* Fri Apr 28 2017 mbologna@suse.de
- Version bump to 1.0.9
* Mon Feb 20 2017 toms@opensuse.org
  Update to 1.0.7:
  * python-build: Add CPython 3.5.3 (#811)
  * python-build: Add CPython 3.4.6 (#812)
  * python-build: Fix tar.gz checksum of CPython 3.6.0 (#793)
  * python-build: Jython installer workaround (#800)
  * python-build: Disable optimization (-O0) when
  - -debug was specified (#808)
* Thu Jan  5 2017 toms@opensuse.org
- Use spec file from dmacvicar, but:
  - Create additional pyenv.d and plugins directories
- Rewrote spec file from scratch
- Update to 1.0.6
* Wed Mar  2 2016 dmacvicar@suse.de
- update to version 20160202
* Fri Jan  8 2016 dmacvicar@suse.de
- update to version 20151222
* Sat Mar 14 2015 dmacvicar@suse.de
- initial package for 20150226
